pyrasite
========

.. split here

Pyrasite lets you to inject arbitrary code into an unaltered running Python
process.

:documentation: http://pyrasite.com
:download: http://pypi.python.org/pypi/pyrasite
:source: http://github.com/lmacken/pyrasite
:screenshots: http://readthedocs.org/docs/pyrasite/en/latest/GUI.html
:mailing list: https://fedorahosted.org/mailman/listinfo/pyrasite
:jenkins: http://ci.csh.rit.edu/view/Pyrasite
:irc: #pyrasite on Freenode

pyrasite-gui
~~~~~~~~~~~~

The gui has been moved into it's own repository: https://github.com/lmacken/pyrasite-gui

.. image:: http://lewk.org/img/pyrasite/pyrasite-info-thumb.png

Authors
~~~~~~~

Luke Macken (`@lmacken <http://twitter.com/lmacken>`_)

.. image:: http://api.coderwall.com/lmacken/endorsecount.png
   :target: http://coderwall.com/lmacken

David Malcolm (dmalcolm ~ redhat ~com)
